@@ -200,6 +200,7 @@ Logger <- R6::R6Class(
       caller = get_caller(-7)
     ){
       if (identical(get("threshold", envir = self), 0L))  return(invisible())
+      LOG_CALL <- sys.call(-1L)  # for error reporting
 
       tryCatch({
         # preconditions
@@ -277,7 +278,9 @@ Logger <- R6::R6Class(
                 get("append", envir = app)(event)
               }
             }, error = function(e) {
+              e$call <- LOG_CALL
               e$appender <- app
+              e$logger <- self
               get("handle_exception", envir = self)(e)
             }
           )
@@ -286,7 +289,11 @@ Logger <- R6::R6Class(
 
         invisible(msg)
       },
-        error = get("handle_exception", envir = self)
+        error = function(e) {
+          e$logger <- self
+          e$call <- LOG_CALL
+          get("handle_exception", envir = self)(e)
+        }
       )
     },
 
@@ -859,6 +866,8 @@ LoggerGlue <- R6::R6Class(
       if (identical(get("threshold", envir = self), 0L))
         return(invisible())
 
+      LOG_CALL <- sys.call(-1L)  # for error reporting
+
       force(.envir)
       tryCatch({
         # preconditions
@@ -921,7 +930,9 @@ LoggerGlue <- R6::R6Class(
                 get("append", envir = app)(event)
               }
             }, error = function(e) {
+              e$call <- LOG_CALL
               e$appender <- app
+              e$logger <- self
               get("handle_exception", envir = self)(e)
             }
           )
@@ -929,7 +940,11 @@ LoggerGlue <- R6::R6Class(
       }
         invisible(msg)
       },
-        error = get("handle_exception", envir = self)
+        error = function(e){
+          e$call <- LOG_CALL
+          e$logger <- self
+          get("handle_exception", envir = self)(e)
+        }
       )
     },
 
